Learn R Programming

haploReconstruct (version 0.1.2)

reconstruct_hb,SNP_time_series-method: Reconstruction of haplotype-blocks

Description

This function reconstructs haplotype-blocks from a SNP_time_series object based on correlated allele frequency changes aacross time points and replicates

Usage

"reconstruct_hb"(object, chrom, min.cl.size = 4, min.cl.cor = 0.8, min.inter = 2, single.win = F, transf = T, scaleSNP = T, pos.cor = F, clusterM = "avLink", eps = 0.3)

Arguments

object
object of the class SNP_time_series data
chrom
a string specifying the name of the chromosome present in the object for which haplotype-block should be reconstructed
min.cl.size
numeric specifying the minimum number of correlated markers in a window for haplotype-block reconstruction
min.cl.cor
numeric specifying the correlation between marker SNPs required using average linkage clustering for markers to be assembled in one cluster
min.inter
numeric specifying the minimum number of markers in two clusters of overlapping windows required to be identical for cluster elongation across windows to build haplotype-blocks
single.win
boolean specifying that are supported by only a cluster in one window are also included in the markers of reconstructed blocks. If FALSE only hbrs are returned that span at least two windows and only markers being present in the intersection between overlapping windows are included.
transf
boolean indicating if frequency data should be square root transformed prior to calaculation pariwise correlations with Pearson's correlation coefficient.
scaleSNP
boolean indicating whether time series allele frequency data for each SNP should be scaled (scaling to a mean of zero and standard deviation of 1.
pos.cor
boolean indicating if negative correlations should be set to zero prior to clustering.
clusterM
indicating the clustering method, choose from: "avLink" (average linkage clustering) and "dbscan".
eps
size of the epsilon neighborhood when clustering with dbscan. For details please refer to the dbscan package.

Value

an object of the class hbr

Details

This function reconstructs haplotype-blocks via markers that show correlated frequency changes across multiple time-points and replicates. In a sliding window based approach SNPs are clustered by average linkage clustering based on correlations of their frequencies across time points and replicates. Clusters are build for each window using the parameters min.cl.size and min.cl.cor. Clustered in overlaping windows (window size/2) are elongated to haplotype-blocks if two adjacent clusters have min.inter identical markers./n Reconstructed haplotype blocks were constructed from at least two overlapping windows and consist of markers that are present in two overlaping window clusters.

References

Franssen et al. 2016, Reconstruction of haplotype-blocks selected during experimental evolution, MBE

See Also

ex_dat initialize_SNP_time_series SNP_time_series