Rdocumentation
powered by
Learn R Programming
haploReconstruct (version 0.1.2)
show,SNP_time_series-method: Display of a SNP_time_series object
Description
This function displays the summarized features of a SNP_time_series object
Usage
"show"(object)
Arguments
object
object of the class SNP_time_series data
Details
This function displays the summarized features of a SNP_time_series object
References
Franssen et al. 2016,
Reconstruction of haplotype-blocks selected during experimental evolution
,
MBE
See Also
ex_dat
initialize_SNP_time_series
SNP_time_series