Usage
"reconstruct_hb"(object, chrom, min.cl.size = 4, min.cl.cor = 0.8, min.inter = 2, single.win = F, transf = T, scaleSNP = T, pos.cor = F, clusterM = "avLink", eps = 0.3)
Arguments
object
object of the class SNP_time_series data
chrom
a string specifying the name of the chromosome present in the object for which
haplotype-block should be reconstructed
min.cl.size
numeric specifying the minimum number of correlated markers in a window for
haplotype-block reconstruction
min.cl.cor
numeric specifying the correlation between marker SNPs required using average
linkage clustering for markers to be assembled in one cluster
min.inter
numeric specifying the minimum number of markers in two clusters of overlapping
windows required to be identical for cluster elongation across windows to build haplotype-blocks
single.win
boolean specifying that are supported by only a cluster in one window are
also included in the markers of reconstructed blocks. If FALSE only hbrs are returned that span
at least two windows and only markers being present in the intersection between overlapping
windows are included.
transf
boolean indicating if frequency data should be square root transformed
prior to calaculation pariwise correlations with Pearson's correlation coefficient.
scaleSNP
boolean indicating whether time series allele frequency data
for each SNP should be scaled (scaling to a mean of zero and standard deviation of 1.
pos.cor
boolean indicating if negative correlations should be set to zero
prior to clustering.
clusterM
indicating the clustering method, choose from: "avLink" (average linkage clustering)
and "dbscan". eps
size of the epsilon neighborhood when clustering with dbscan.
For details please refer to the dbscan package.